const buildState = ({ theme, color }) => ({
	borderColor: theme(color)
});

const field = (theme) => ({
	'.form-field-container': {
		marginBottom: '0',
		paddingTop: '.5rem',
		paddingBottom: '.25rem'
	},
	'.field': {
		'&-container': {
			position: 'relative',
			fontSize: '16px',
			display: 'flex',
			minHeight: '2rem',
			padding: '.75rem 0 .25rem .5rem',
			border: `1px solid ${theme('colors.field.input.border')}`,
			borderRadius: theme('borderRadius.lg'),
			'&--info': buildState({ theme, color: 'colors.field.info.border' }),
			'&--success': buildState({ theme, color: 'colors.field.success.border' }),
			'&--warning': buildState({ theme, color: 'colors.field.warning.border' }),
			'&--error': buildState({ theme, color: 'colors.field.error.border' }),
			'&--multiline': {
				height: 'auto'
			},
			'&--nolabel': {
				border: 'none'
			}
		},
		'&-label': {
			color: theme('colors.field.label.color'),
			backgroundColor: theme('colors.field.label.background'),
			position: 'absolute',
			textTransform: 'uppercase',
			top: '-10px',
			left: '5px',
			fontSize: '12px',
			padding: '0 4px',
			fontWeight: 300,
			'& > svg': {
				fontSize: '1.2rem'
			},
			'&--disabled': {
				color: theme('colors.field.disabled.color')
			}
		},
		'&-input': {
			backgroundColor: theme('colors.field.input.background'),
			outline: 'none',
			cursor: 'text',
			width: 'calc(100% - 0.75rem)',
			'&:read-only': {
				cursor: 'auto'
			},
			'&--multiline': {
				minHeight: '3rem'
			}
		},
		'&-icon': {
			cursor: 'pointer',
			color: theme('colors.field.icon.color'),
			fontSize: '22px'
		}
	},
	'.checkbox-container, .radiobutton-container': {
		'.field-checkbox, .field-radio': {
			display: 'flex',
			alignItems: 'center',
			cursor: 'pointer',
			'& > svg': {
				color: theme('colors.field.icon.color')
			},
			'&--disabled': {
				color: theme('colors.field.disabled.color'),
				cursor: 'not-allowed',
				'& > svg': {
					color: theme('colors.field.disabled.color'),
					cursor: 'not-allowed'
				}
			}
		},
		'.field-radiobutton': {
			display: 'flex',
			padding: '.25rem .5rem',
			alignItems: 'center',
			height: '100%',
			cursor: 'pointer',
			borderRadius: theme('borderRadius.lg'),
			border: `1px solid transparent`,
			'&--disabled': {
				color: theme('colors.field.disabled.color'),
				cursor: 'not-allowed'
			},
			'&--active': {
				color: theme('colors.field.radioButton.active.color'),
				borderColor: theme('colors.field.radioButton.active.border'),
				backgroundColor: theme('colors.field.radioButton.active.background')
			}
		}
	},
	'.field-validationMessage': {
		color: theme('colors.field.error.border'),
		marginLeft: '0.5rem',
		fontSize: '0.75rem'
	}
});

module.exports = ({ addComponents, theme }) => {
	addComponents(field(theme));
};

module.exports.field = field;
